<?php

class Lm {

    private $db;
    public function __construct()
    {
        $this->db = new Database;
    }

    public function EducatecActividadesBuscar($cedula,$curso){
    $this->db->query('SELECT * FROM edu_actividades WHERE cedula= :id_Cedula and curso= :id_Curso order by entrega');
    $this->db->bind(':id_Curso', $curso);
    $this->db->bind(':id_Cedula', $cedula);
    $result = $this->db->resultSet();
    return $result;
    }

    public function EducatecEstudiantesBuscar($curso){
    $this->db->query('SELECT * FROM alumnos WHERE curso= :id_Curso order by apellidos,nombres');
    $this->db->bind(':id_Curso', $curso);
    $result = $this->db->resultSet();
            if(empty($result)){
            return false;
            }else{
            return $result;
            }
    }

    public function EducatecInstrumentoBuscar($id){
    $this->db->query('SELECT * FROM edu_actividades WHERE id= :id');
    $this->db->bind(':id', $id);
    $result = $this->db->single();
    return $result;
    }

    public function EducatecEstudianteBuscar($id){
    $this->db->query('SELECT * FROM alumnos WHERE cedula= :ced');
    $this->db->bind(':ced', $id);
    $result = $this->db->single();
    return $result;
    }

    public function EducatecEstudianteEditar($data){
    $this->db->query('UPDATE alumnos SET apellidos= :lms_ape,nombres= :lms_nom,cod_tlfc= :lms_cco,tlfc= :lms_cel,email= :lms_mai
    WHERE cedula= :lms_ced');
    $this->db->bind(':lms_ced', $data['lms_ced']);
    $this->db->bind(':lms_ape', $data['lms_ape']);
    $this->db->bind(':lms_nom', $data['lms_nom']);
    $this->db->bind(':lms_cco', $data['lms_cco']);
    $this->db->bind(':lms_cel', $data['lms_cel']);
    $this->db->bind(':lms_mai', $data['lms_mai']);
    if($this->db->execute()){
    //return true;
    }else{
    //return false;
    }
    }

    public function EducatecInstrumentoGuardar($data){
    //$this->db->beginTransaction();
    $this->db->query('INSERT INTO edu_actividades(cedula,curso,titulo,instrucciones,puntuacion,entrega,tipo)
    VALUES (:lms_educ, :lms_curso, :lms_titu, :lms_inst, :lms_ptos, :lms_fec, :lms_tipo)');
    $this->db->bind(':lms_educ', $data['lms_educ']);
    $this->db->bind(':lms_curso', $data['lms_curso']);
    $this->db->bind(':lms_titu', $data['lms_titu']);
    $this->db->bind(':lms_inst', $data['lms_inst']);
    $this->db->bind(':lms_ptos', $data['lms_ptos']);
    $this->db->bind(':lms_fec', $data['lms_fec']);
    $this->db->bind(':lms_tipo', $data['lms_tipo']);
    if($this->db->execute()){
    //return true;
    }else{
    //return false;
    }
    }

    public function EducatecInstrumentoEditar($data){
    //$this->db->beginTransaction();
    $this->db->query('UPDATE edu_actividades SET titulo= :lms_titu,instrucciones= :lms_inst,puntuacion= :lms_ptos,entrega= :lms_fec,tipo= :lms_tipo
    WHERE id= :lms_id');
    $this->db->bind(':lms_id', $data['lms_id']);
    $this->db->bind(':lms_titu', $data['lms_titu']);
    $this->db->bind(':lms_inst', $data['lms_inst']);
    $this->db->bind(':lms_ptos', $data['lms_ptos']);
    $this->db->bind(':lms_fec', $data['lms_fec']);
    $this->db->bind(':lms_tipo', $data['lms_tipo']);
    if($this->db->execute()){
    //return true;
    }else{
    //return false;
    }
    }

    public function EducatecInstrumentoPub($data){
    $this->db->query('UPDATE edu_actividades SET publicado= :lms_pub WHERE id= :lms_id');
    $this->db->bind(':lms_id', $data['lms_id']);
    $this->db->bind(':lms_pub', $data['lms_pub']);
    $this->db->execute();
    $this->db->submitTransaction();
    //if($this->db->execute()){
    //return true;
    //}else{
    //return false;
    //}
    }

    public function EducatecAnuncioGuardar($data){
    $this->db->query('INSERT INTO edu_anuncios(curso,educador,anuncio)
    VALUES (:id_Curso, :id_Educa, :id_Anun)');
    $this->db->bind(':id_Educa', $data['id_Educa']);
    $this->db->bind(':id_Curso', $data['id_Curso']);
    $this->db->bind(':id_Anun', $data['id_Anun']);
    if($this->db->execute()){
    //return true;
    }else{
    //return false;
    }
    }

    public function EducatecAnuncioBuscar($data1,$data2){
    $this->db->query('SELECT * FROM edu_anuncios WHERE educador= :id_Educa and curso= :id_Curso order by id desc');
    $this->db->bind(':id_Educa', $data1);
    $this->db->bind(':id_Curso', $data2);
    $result = $this->db->resultSet();
    //$this->db->fintrans();
    return $result;
    }

    public function EducatecAnuncioDel($id){
        $this->db->query('DELETE FROM edu_anuncios WHERE id = :id');
        $this->db->bind(':id', $id);
        if($this->db->execute()){
            return true;
        }else{
            return false;
        }
    }

    public function EducatecInstrumentoDel($id,$cedula){
    $this->db->query('DELETE FROM edu_actividades WHERE id = :id and cedula= :id_Cedula');
    $this->db->bind(':id', $id);
    $this->db->bind(':id_Cedula', $cedula);
    if($this->db->execute()){
            return true;
        }else{
            return false;
        }
    }

    public function EducatecInstrumentoIr($data){
    $this->db->query('SELECT * FROM edu_actividades WHERE id= :id');
    $this->db->bind(':id', $data);
    $row = $this->db->single();
    return $row;
    }

    public function EducatecCuestionarioBuscar($cedula,$id,$tipo){
    $this->db->query('SELECT * FROM edu_actividades WHERE id= :id and cedula= :id_Cedula and tipo= :tipo');
    $this->db->bind(':id', $id);
    $this->db->bind(':id_Cedula', $cedula);
    $this->db->bind(':tipo', $tipo);
    $result = $this->db->single();
    return $result;
    }

    public function EducatecPreguntaBuscar($dato){
    $this->db->query('SELECT * FROM edu_preguntas WHERE id_actividad = :id_actividad order by id');
    $this->db->bind(':id_actividad', $dato);
    $result = $this->db->resultSet();
    return $result;
    }

    public function EducatecPreguntaBuscarUna($dato){
    $this->db->query('SELECT * FROM edu_preguntas WHERE id = :id');
    $this->db->bind(':id', $dato);
    $result = $this->db->single();
    return $result;
    }
    public function EducatecRespuestaBuscarUna($dato){
    $this->db->query('SELECT * FROM edu_respuestas WHERE pregunta_nro = :id order by id');
    $this->db->bind(':id', $dato);
    $result = $this->db->resultSet();
    return $result;
    }

    public function EducatecRespuestaBuscar($dato){
    $this->db->query('SELECT * FROM edu_respuestas WHERE id_actividad = :id_actividad order by id_actividad,pregunta_nro');
    $this->db->bind(':id_actividad', $dato);
    $result = $this->db->resultSet();
    return $result;
    }

    public function EducatecPreguntaDel($dato){
    $this->db->query('DELETE FROM edu_preguntas WHERE id = :id');
    $this->db->bind(':id', $dato);
        if($this->db->execute()){
        //    return true;
        }else{
            return false;
        }

    $this->db->query('DELETE FROM edu_respuestas WHERE pregunta_nro = :id');
    $this->db->bind(':id', $dato);
        if($this->db->execute()){
            return true;
        }else{
            return false;
        }

    }

    public function EducatecCuestionarioGuardar($dataa){
    foreach($dataa as $data){
    $this->db->query('INSERT INTO edu_preguntas(id_actividad,pregunta_nro,pregunta,pregunta_tipo,puntos,correcta)
    VALUES (:id_actividad, :pregunta_nro, :pregunta, :tipo_preg, :puntos, :op)');
    $this->db->bind(':id_actividad', $data['id_actividad']);
    $this->db->bind(':pregunta_nro', $data['pregunta_nro']);
    $this->db->bind(':pregunta', $data['pregunta']);
    $this->db->bind(':tipo_preg', $data['tipo_preg']);
    $this->db->bind(':puntos', $data['puntos']);
    $this->db->bind(':op', $data['op']);
    $id_rec = $this->db->executelast();
    //    if($this->db->execute()){
    return $id_rec;
    //    }else{
        //return false;
    //    }
    }
    }

    public function EducatecCuestionarioGuardarResp($dataa){
    foreach($dataa as $data){
    $this->db->query('INSERT INTO edu_respuestas(id_actividad,pregunta_nro,respuesta,respuesta2,respuesta3,respuesta_tipo)
    VALUES (:id_actividad, :pregunta_nro, :respuesta, :respuesta2, :respuesta3, :respuesta_tipo)');
    $this->db->bind(':id_actividad', $data['id_actividad']);
    $this->db->bind(':pregunta_nro', $data['pregunta_nro']);
    $this->db->bind(':respuesta', $data['respuesta']);
    $this->db->bind(':respuesta2', $data['respuesta2']);
    $this->db->bind(':respuesta3', $data['respuesta3']);
    $this->db->bind(':respuesta_tipo', $data['respuesta_tipo']);
        if($this->db->execute()){
        //return true;
        }else{
        //return false;
        }
    }
    }

    public function EducatecCuestionarioEditar($dataa){
    //var_dump($data);
    foreach($dataa as $data){
    $this->db->query('UPDATE edu_preguntas SET id_actividad= :id_actividad,pregunta_nro= :pregunta_nro,pregunta= :pregunta,pregunta_tipo= :tipo_preg,puntos= :puntos,correcta= :op
    WHERE id= :id_preg');
    $this->db->bind(':id_preg', $data['id_preg']);
    $this->db->bind(':id_actividad', $data['id_actividad']);
    $this->db->bind(':pregunta_nro', $data['pregunta_nro']);
    $this->db->bind(':pregunta', $data['pregunta']);
    $this->db->bind(':tipo_preg', $data['tipo_preg']);
    $this->db->bind(':puntos', $data['puntos']);
    $this->db->bind(':op', $data['op']);
    //$id_rec = $this->db->executelast();
    $this->db->execute();
    //return $id_rec;
    //    }else{
        //return false;
    //    }
    }
    }

    public function EducatecCuestionarioEditarResp($dataa){
    foreach($dataa as $data){
    $this->db->query('UPDATE edu_respuestas SET id_actividad= :id_actividad,respuesta= :respuesta,respuesta2= :respuesta2,respuesta3= :respuesta3,respuesta_tipo= :respuesta_tipo
    WHERE pregunta_nro= :pregunta_nro');
    $this->db->bind(':id_actividad', $data['id_actividad']);
    $this->db->bind(':pregunta_nro', $data['pregunta_nro']);
    $this->db->bind(':respuesta', $data['respuesta']);
    $this->db->bind(':respuesta2', $data['respuesta2']);
    $this->db->bind(':respuesta3', $data['respuesta3']);
    $this->db->bind(':respuesta_tipo', $data['respuesta_tipo']);
        if($this->db->execute()){
        //return true;
        }else{
        //return false;
        }
    }
    }



    public function EducatecAP(){

    $this->db->query('SELECT * FROM alumnos');
    $result = $this->db->resultSet();
//var_dump($result);
    foreach ($result as $p){

    $this->db->query('UPDATE alumnos SET password= :respuesta');
    $this->db->bind(':respuesta', password_hash($p->cedula, PASSWORD_DEFAULT));
    $this->db->execute();
    }

    }
}