<?php

class Lms extends Controller{

    public function __construct()
    {

    if(!isLoggedIn()){
            redirect('users/login');
    }
        //new model instance
    $this->EducaModel = $this->model('Educador');
    $this->LmsModel = $this->model('Lm');
    //    $this->userModel = $this->model('User');
    //    $this->edifModel = $this->model('Edificio');
    }

    public function inicio(){
    $this->index(1);
    }

    public function index(){
    redirect('educadores/');
    }

    public function escritorio($id){
        //$this->LmsModel->EducatecAP();
        $idx=$_SESSION['email'];

        if($educador = $this->EducaModel->EducaById($idx)){
        }else{
        redirect('educadores/');
        }

        $educa_ced=$educador->cedula;
        $datos_educa = [
        'id_ed' => $educador->cedula,
        'ape_ed' => $educador->apellidos,
        'nom_ed' => $educador->nombres,
        'id_curso' => $id,
        ];

        $anuncios = $this->LmsModel->EducatecAnuncioBuscar($educa_ced,$id);

    $loader = new \Twig\Loader\FilesystemLoader('../app/views');
    $twig = new \Twig\Environment($loader, ['cache' => '../app/cache','auto_reload' => true,'debug' => true,]);
    $twig->addGlobal('names',$_SESSION['name']);
    //$twig->addExtension(new IntlExtension());
    $layout = $twig->load('inc/base.html.twig');
    echo $twig->render('lms/escritorio.html.twig', ['datos_educa' => $datos_educa,'anuncios' => $anuncios]);
    }

    public function instrumentos($id){
        $idx=$_SESSION['email'];

        if($educador = $this->EducaModel->EducaById($idx)){
        }else{
        redirect('educadores/');
        }

        $educa_ced=$educador->cedula;
        $datos_educa = [
        'ced_ed' => $educador->cedula,
        'ape_ed' => $educador->apellidos,
        'nom_ed' => $educador->nombres,
        'id_curso' => $id,
        ];

        $actividades = $this->LmsModel->EducatecActividadesBuscar($educa_ced,$id);

    //var_dump($actividades);
    $loader = new \Twig\Loader\FilesystemLoader('../app/views');
    $twig = new \Twig\Environment($loader, ['cache' => '../app/cache','auto_reload' => true,'debug' => true,]);
    $twig->addGlobal('names',$_SESSION['name']);
    $layout = $twig->load('inc/base.html.twig');
    echo $twig->render('lms/trabajos.html.twig', ['datos_educa' => $datos_educa,'actividades' => $actividades]);
    }

    public function EduEstudianteBuscar($ced){
        $idx=$_SESSION['email'];

        if($educador = $this->EducaModel->EducaById($idx)){
        }else{
        redirect('educadores/');
        }

        $educa_ced=$educador->cedula;
        $datos_educa = [
        'ced_ed' => $educador->cedula,
        'ape_ed' => $educador->apellidos,
        'nom_ed' => $educador->nombres,
        //'id_curso' => $id,
        ];

    //    $cuestionarios = $this->LmsModel->EducatecCuestionarioBuscar($educa_ced,$id,'Cuestionario');
        $estudiante = $this->LmsModel->EducatecEstudianteBuscar($ced);

        //var_dump($estudiante);
        echo json_encode($estudiante);


    //


    //$loader = new \Twig\Loader\FilesystemLoader('../app/views');
    //$twig = new \Twig\Environment($loader, ['cache' => '../app/cache','auto_reload' => true,'debug' => true,]);
    //$twig->addGlobal('names',$_SESSION['name']);
    //$layout = $twig->load('inc/base.html.twig');
    //echo $twig->render('lms/cuestionario.html.twig', ['respuestas' => $respuestas,'preguntas' => $preguntas,'datos_educa' => $datos_educa,'cuestionarios' => $cuestionarios]);
    }

    public function EduEstudianteEditar(){
    $_POST = filter_input_array(INPUT_POST, FILTER_SANITIZE_STRING);
    if($_SERVER['REQUEST_METHOD'] == 'POST'){

        $data = [
        'lms_ced' =>strtoupper(trim($_POST['cedula'])),
        'lms_ape' =>strtoupper(trim($_POST['apellidos'])),
        'lms_nom' =>strtoupper(trim($_POST['nombres'])),
        'lms_cco' =>trim($_POST['codigo']),
        'lms_cel' =>trim($_POST['celular']),
        'lms_mai' =>strtolower(trim($_POST['correo'])),
        'lms_cur' =>strtolower(trim($_POST['id_Curso'])),
    ];
var_dump($data);
//exit;
            $error_msj='';
            $error_sw=0;

            if(strlen(trim($data['lms_ape']))<=0){
                $data['campoE1'] = 'Escriba un apellido...';
                $error_msj= 'Escriba un Nombre...';
                $error_sw=1;
            }
            if(strlen(trim($data['lms_nom']))<=0){
                $data['campoE1'] = 'Escriba las nombre...';
                $error_msj= 'Escriba un Apellido...';
                $error_sw=1;
            }
            if($error_sw==1){
                $data['campoE1'] = 'Escriba un Apellido...';
                $error_msj= 'Escriba la puntuacion...';
                $error_sw=1;
            }

            if($error_sw==0){
            $this->LmsModel->EducatecEstudianteEditar($data);
            }

            redirect('lms/estudiantes/'.$data['lms_cur']);

        }
    }

    public function estudiantes($id){
        $idx=$_SESSION['email'];

        if($educador = $this->EducaModel->EducaById($idx)){
        }else{
        redirect('educadores/');
        }

        $educa_ced=$educador->cedula;
        $datos_educa = [
        'ced_ed' => $educador->cedula,
        'ape_ed' => $educador->apellidos,
        'nom_ed' => $educador->nombres,
        'id_curso' => $id,
        ];

        $estudiantes = $this->LmsModel->EducatecEstudiantesBuscar($id);
        if(!$estudiantes){
        redirect('educadores/');
        }

    //var_dump($estudiantes);
    //exit;
    $loader = new \Twig\Loader\FilesystemLoader('../app/views');
    $twig = new \Twig\Environment($loader, ['cache' => '../app/cache','auto_reload' => true,'debug' => true,]);
    $twig->addGlobal('names',$_SESSION['name']);
    $layout = $twig->load('inc/base.html.twig');
    echo $twig->render('lms/estudiantes.html.twig', ['datos_educa' => $datos_educa,'estudiantes' => $estudiantes]);
    }

    public function cuestionario($id){
        $idx=$_SESSION['email'];

        if($educador = $this->EducaModel->EducaById($idx)){
        }else{
        redirect('educadores/');
        }

        $educa_ced=$educador->cedula;
        $datos_educa = [
        'ced_ed' => $educador->cedula,
        'ape_ed' => $educador->apellidos,
        'nom_ed' => $educador->nombres,
        'id_curso' => $id,
        ];

        $cuestionarios = $this->LmsModel->EducatecCuestionarioBuscar($educa_ced,$id,'Cuestionario');
        $preguntas = $this->LmsModel->EducatecPreguntaBuscar($id);
        $respuestas = $this->LmsModel->EducatecRespuestaBuscar($id);

    $loader = new \Twig\Loader\FilesystemLoader('../app/views');
    $twig = new \Twig\Environment($loader, ['cache' => '../app/cache','auto_reload' => true,'debug' => true,]);
    $twig->addGlobal('names',$_SESSION['name']);
    $layout = $twig->load('inc/base.html.twig');
    echo $twig->render('lms/cuestionario.html.twig', ['respuestas' => $respuestas,'preguntas' => $preguntas,'datos_educa' => $datos_educa,'cuestionarios' => $cuestionarios]);
    }

    public function cuestionario_ver($id){
        $idx=$_SESSION['email'];

        if($educador = $this->EducaModel->EducaById($idx)){
        }else{
        redirect('educadores/');
        }

        $educa_ced=$educador->cedula;
        $datos_educa = [
        'ced_ed' => $educador->cedula,
        'ape_ed' => $educador->apellidos,
        'nom_ed' => $educador->nombres,
        'id_curso' => $id,
        ];

        $cuestionarios = $this->LmsModel->EducatecCuestionarioBuscar($educa_ced,$id,'Cuestionario');
        $preguntas = $this->LmsModel->EducatecPreguntaBuscar($id);
        $respuestas = $this->LmsModel->EducatecRespuestaBuscar($id);

    $loader = new \Twig\Loader\FilesystemLoader('../app/views');
    $twig = new \Twig\Environment($loader, ['cache' => '../app/cache','auto_reload' => true,'debug' => true,]);
    $twig->addGlobal('names',$_SESSION['name']);
    $layout = $twig->load('inc/base.html.twig');
    echo $twig->render('lms/cuestionario_ver.html.twig', ['respuestas' => $respuestas,'preguntas' => $preguntas,'datos_educa' => $datos_educa,'cuestionarios' => $cuestionarios]);
    }

    public function EduAnuncioCrear(){
    $AnuncioCrea=$_POST;
    $idd=$_POST['id_idd'];

    $educadorx = $this->LmsModel->EducatecAnuncioGuardar($AnuncioCrea);

    redirect('lms/escritorio/'.$idd);
    }

    public function EduAnuncioDel($id){
    //$AnuncioCrea=$_POST;
    //$idd=$_POST['id_idd'];
    $idc=explode('$',$id);

    $educadorx = $this->LmsModel->EducatecAnuncioDel($idc[0]);

    redirect('lms/escritorio/'.$idc[1]);
    }

    public function EduInstrumentoBuscar($id){
        $idx=$_SESSION['email'];

        if($educador = $this->EducaModel->EducaById($idx)){
        }else{
        redirect('educadores/');
        }

        $educa_ced=$educador->cedula;
        $datos_educa = [
        'ced_ed' => $educador->cedula,
        'ape_ed' => $educador->apellidos,
        'nom_ed' => $educador->nombres,
        'id_curso' => $id,
        ];

    //    $cuestionarios = $this->LmsModel->EducatecCuestionarioBuscar($educa_ced,$id,'Cuestionario');
        $instrumentos = $this->LmsModel->EducatecInstrumentoBuscar($id);


        echo json_encode($instrumentos);


    //var_dump($preguntas);


    //$loader = new \Twig\Loader\FilesystemLoader('../app/views');
    //$twig = new \Twig\Environment($loader, ['cache' => '../app/cache','auto_reload' => true,'debug' => true,]);
    //$twig->addGlobal('names',$_SESSION['name']);
    //$layout = $twig->load('inc/base.html.twig');
    //echo $twig->render('lms/cuestionario.html.twig', ['respuestas' => $respuestas,'preguntas' => $preguntas,'datos_educa' => $datos_educa,'cuestionarios' => $cuestionarios]);
    }

    public function EduInstrumentoGuardar(){
    $_POST = filter_input_array(INPUT_POST, FILTER_SANITIZE_STRING);
    if($_SERVER['REQUEST_METHOD'] == 'POST'){

        $data = [
        'lms_titu' =>strtoupper(trim($_POST['titulo'])),
        'lms_inst' =>trim($_POST['instrucciones']),
        'lms_ptos' =>trim($_POST['puntos']),
        'lms_educ' =>trim($_POST['id_Educa']),
        'lms_curso' =>trim($_POST['id_Curso']),
        'lms_fec' =>trim($_POST['fecha']),
        'lms_tipo' =>trim($_POST['tipo']),
    ];
var_dump($data);
//exit;
            $error_msj='';
            $error_sw=0;

            if(strlen(trim($data['lms_titu']))<=0){
                $data['campoE1'] = 'Escriba un Titulo...';
                $error_msj= 'Escriba un Nombre...';
                $error_sw=1;
            }
            if(strlen(trim($data['lms_inst']))<=0){
                $data['campoE1'] = 'Escriba las Instrucciones...';
                $error_msj= 'Escriba un Apellido...';
                $error_sw=1;
            }
            if($error_sw==1){
                $data['campoE1'] = 'Escriba un Apellido...';
                $error_msj= 'Escriba la puntuacion...';
                $error_sw=1;
            }

            if($error_sw==0){

            $this->LmsModel->EducatecInstrumentoGuardar($data);
            }

            redirect('lms/actividades/'.$data['lms_curso']);

        }
    }


    public function EduInstrumentoEditar(){
    $_POST = filter_input_array(INPUT_POST, FILTER_SANITIZE_STRING);
    if($_SERVER['REQUEST_METHOD'] == 'POST'){

        $data = [
        'lms_titu' =>strtoupper(trim($_POST['titulo'])),
        'lms_inst' =>trim($_POST['instrucciones']),
        'lms_ptos' =>trim($_POST['puntos']),
        'lms_educ' =>trim($_POST['id_Educa']),
        'lms_curso' =>trim($_POST['id_Curso']),
        'lms_fec' =>trim($_POST['fecha']),
        'lms_tipo' =>trim($_POST['tipo']),
        'lms_id' =>trim($_POST['id_Inst']),
    ];
var_dump($data);
//exit;
            $error_msj='';
            $error_sw=0;

            if(strlen(trim($data['lms_titu']))<=0){
                $data['campoE1'] = 'Escriba un Titulo...';
                $error_msj= 'Escriba un Nombre...';
                $error_sw=1;
            }
            if(strlen(trim($data['lms_inst']))<=0){
                $data['campoE1'] = 'Escriba las Instrucciones...';
                $error_msj= 'Escriba un Apellido...';
                $error_sw=1;
            }
            if($error_sw==1){
                $data['campoE1'] = 'Escriba un Apellido...';
                $error_msj= 'Escriba la puntuacion...';
                $error_sw=1;
            }

            if($error_sw==0){
            $this->LmsModel->EducatecInstrumentoEditar($data);
            }

            redirect('lms/actividades/'.$data['lms_curso']);

        }
    }
    public function publicar($id){
        $idx=$_SESSION['email'];

        if($educador = $this->EducaModel->EducaById($idx)){
        }else{
        redirect('educadores/');
        }

        $instrumentos = $this->LmsModel->EducatecInstrumentoBuscar($id);
        var_dump($instrumentos).'<br><br><br>';
        $idCurso=$instrumentos->curso;
        if($instrumentos->publicado == "N"){
        $publicado="S";
        }else{
        $publicado="N";
        }

        $data = [
        'lms_pub' => $publicado,
        'lms_id'  => $id,
        ];


    $this->LmsModel->EducatecInstrumentoPub($data);

    $instrumentos = $this->LmsModel->EducatecInstrumentoBuscar($id);
    //var_dump($instrumentos);
    //exit;
    redirect('lms/instrumentos/'.$idCurso);

    }


    public function EduInstrumentoDel($del){
        $idx=$_SESSION['email'];

        if($educador = $this->EducaModel->EducaById($idx)){
        }else{
        redirect('educadores/');
        }

        $educa_ced=$educador->cedula;
        $datos_educa = [
        'ced_ed' => $educador->cedula,
        'ape_ed' => $educador->apellidos,
        'nom_ed' => $educador->nombres,
        ];

        $dataa= explode('$',$del);

        $this->LmsModel->EducatecInstrumentoDel($dataa[0],$educa_ced);

    redirect('lms/actividades/'.$dataa[1]);
    }


    public function EduPreguntaBuscar($id){
        $idx=$_SESSION['email'];

        if($educador = $this->EducaModel->EducaById($idx)){
        }else{
        redirect('educadores/');
        }

        $educa_ced=$educador->cedula;
        $datos_educa = [
        'ced_ed' => $educador->cedula,
        'ape_ed' => $educador->apellidos,
        'nom_ed' => $educador->nombres,
        'id_curso' => $id,
        ];

    //    $cuestionarios = $this->LmsModel->EducatecCuestionarioBuscar($educa_ced,$id,'Cuestionario');
        $preguntas = $this->LmsModel->EducatecPreguntaBuscarUna($id);
        if($preguntas->pregunta_tipo=='SMT'){
        $respuestas = $this->LmsModel->EducatecRespuestaBuscarUna($id);
        echo json_encode(array($preguntas,$respuestas));
        }else{
        echo json_encode($preguntas);
        }

    //var_dump($preguntas);


    //$loader = new \Twig\Loader\FilesystemLoader('../app/views');
    //$twig = new \Twig\Environment($loader, ['cache' => '../app/cache','auto_reload' => true,'debug' => true,]);
    //$twig->addGlobal('names',$_SESSION['name']);
    //$layout = $twig->load('inc/base.html.twig');
    //echo $twig->render('lms/cuestionario.html.twig', ['respuestas' => $respuestas,'preguntas' => $preguntas,'datos_educa' => $datos_educa,'cuestionarios' => $cuestionarios]);
    }

    public function EduPreguntaDel($del){
        $idx=$_SESSION['email'];

        if($educador = $this->EducaModel->EducaById($idx)){
        }else{
        redirect('educadores/');
        }


/*
        $dataa= explode('$',$del);

        if($educador = $this->LmsModel->EducaById($idx)){
        }else{
        redirect('educadores/');
        }*/

        $this->LmsModel->EducatecPreguntaDel($del);

    redirect('lms/cuestionario/'.$dataa[1]);
    }

    public function EduCuestionarioCrear(){

    $AnuncioCrea=$_POST;
    $id_Curso=$AnuncioCrea['id_Curso'];
    var_dump($AnuncioCrea);

            $pregunta[] =
            [
            'id_preg'       => $AnuncioCrea['id_preg'],
            'id_actividad'  => $AnuncioCrea['id_Curso'],
            'pregunta_nro'  => $AnuncioCrea['nro_preg'],
            'pregunta'      => $AnuncioCrea['preg'],
            'tipo_preg'     => $AnuncioCrea['tipo_preg'],
            'puntos'        => $AnuncioCrea['puntos'],
            'op'            => $AnuncioCrea['op']
            ];
    if($AnuncioCrea['enviar']=='Guardar Pregunta'){
    $id_preg=$this->LmsModel->EducatecCuestionarioGuardar($pregunta);

            if($AnuncioCrea['tipo_preg']=='SMT'){
            $respuesta[] =
            [
            'id_preg'           => $AnuncioCrea['id_preg'],
            'id_actividad'      => $AnuncioCrea['id_Curso'],
            'pregunta_nro'      => $id_preg,
            'respuesta'         => $AnuncioCrea['resp1'],
            'respuesta2'        => $AnuncioCrea['resp2'],
            'respuesta3'        => $AnuncioCrea['resp3'],
            'respuesta_tipo'    => 'V'
            ];
            $this->LmsModel->EducatecCuestionarioGuardarResp($respuesta);
            }

    }else{
    $id_preg=$this->LmsModel->EducatecCuestionarioEditar($pregunta);
        if($AnuncioCrea['tipo_preg']=='SMT'){
            $respuesta[] =
            [
            'id_actividad'      => $AnuncioCrea['id_Curso'],
            'pregunta_nro'      => $AnuncioCrea['id_preg'],
            'respuesta'         => $AnuncioCrea['resp1'],
            'respuesta2'        => $AnuncioCrea['resp2'],
            'respuesta3'        => $AnuncioCrea['resp3'],
            'respuesta_tipo'    => 'V'
            ];
        $this->LmsModel->EducatecCuestionarioEditarResp($respuesta);
        }
    }
    //redirect('lms/cuestionario/'.$id_Curso);
    }

}
